/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_UyBlHbGN);
  numBytes += sLine_init(&sLine_GfSDgodm);
  numBytes += sLine_init(&sLine_Jcsi5RKj);
  numBytes += sLine_init(&sLine_8mDJExTU);
  numBytes += sLine_init(&sLine_yOqAnyen);
  numBytes += sBiquad_init(&sBiquad_s_yd8cOvUV);
  numBytes += sLine_init(&sLine_KgWWoASw);
  numBytes += sLine_init(&sLine_HNBfDR7m);
  numBytes += sLine_init(&sLine_041Y24p5);
  numBytes += sLine_init(&sLine_3ZS4U94s);
  numBytes += sBiquad_init(&sBiquad_s_8C9HUTKH);
  numBytes += sLine_init(&sLine_zqRGVldx);
  numBytes += sLine_init(&sLine_55e7LEFj);
  numBytes += sLine_init(&sLine_I6iQ5Dl1);
  numBytes += sLine_init(&sLine_f0jLkSE3);
  numBytes += sLine_init(&sLine_0EPEu8zM);
  numBytes += sBiquad_init(&sBiquad_s_XAUBpKDt);
  numBytes += sLine_init(&sLine_omuzDoar);
  numBytes += sLine_init(&sLine_Knjtg7lq);
  numBytes += sLine_init(&sLine_43cUCiCI);
  numBytes += sLine_init(&sLine_kF9IYD2D);
  numBytes += sLine_init(&sLine_XBdSMZNu);
  numBytes += sBiquad_init(&sBiquad_s_gUWSQppA);
  numBytes += sLine_init(&sLine_8XYj1W8Q);
  numBytes += sLine_init(&sLine_MvrIKQ1z);
  numBytes += sLine_init(&sLine_4B38cixE);
  numBytes += sLine_init(&sLine_wuqz9BV6);
  numBytes += sBiquad_init(&sBiquad_s_sI049mM8);
  numBytes += sLine_init(&sLine_lRWi48u1);
  numBytes += sLine_init(&sLine_02MIuWpd);
  numBytes += sLine_init(&sLine_9CpKXfg5);
  numBytes += sLine_init(&sLine_ojllg8oB);
  numBytes += sLine_init(&sLine_r93ah6Ha);
  numBytes += sBiquad_init(&sBiquad_s_Rp1yDbcg);
  numBytes += sLine_init(&sLine_fPy7S1Lw);
  numBytes += sPhasor_k_init(&sPhasor_JK0yXyOj, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_VQsFiIZ6);
  numBytes += sRPole_init(&sRPole_dxa3ooJ7);
  numBytes += sRPole_init(&sRPole_LTElx4B3);
  numBytes += sTabhead_init(&sTabhead_E53RgqeD, &hTable_ZMm5JoFr);
  numBytes += sTabread_init(&sTabread_xlYXKQEY, &hTable_ZMm5JoFr, false);
  numBytes += sTabread_init(&sTabread_upzAvKBI, &hTable_ZMm5JoFr, false);
  numBytes += sLine_init(&sLine_m22joC8F);
  numBytes += sTabhead_init(&sTabhead_u0dkb80b, &hTable_vugnvzdv);
  numBytes += sTabread_init(&sTabread_AQdAyFVp, &hTable_vugnvzdv, false);
  numBytes += sTabread_init(&sTabread_9mWVf6Qr, &hTable_vugnvzdv, false);
  numBytes += sLine_init(&sLine_sZVOsb6g);
  numBytes += sTabwrite_init(&sTabwrite_JCiXHnIr, &hTable_vugnvzdv);
  numBytes += sTabwrite_init(&sTabwrite_fxBynssm, &hTable_ZMm5JoFr);
  numBytes += sLine_init(&sLine_PKaWmDGr);
  numBytes += sPhasor_k_init(&sPhasor_7vZAAs1m, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_K9KPnW4d);
  numBytes += sRPole_init(&sRPole_OFJRL5i7);
  numBytes += sRPole_init(&sRPole_B0xdvwD7);
  numBytes += sTabhead_init(&sTabhead_sVRCP0zD, &hTable_kCggm0SS);
  numBytes += sTabread_init(&sTabread_2a9Sc9W0, &hTable_kCggm0SS, false);
  numBytes += sTabread_init(&sTabread_P2wNITmi, &hTable_kCggm0SS, false);
  numBytes += sLine_init(&sLine_7Lc04QrL);
  numBytes += sTabhead_init(&sTabhead_ShpwhOqK, &hTable_BkpPqQni);
  numBytes += sTabread_init(&sTabread_rgtl8ZLO, &hTable_BkpPqQni, false);
  numBytes += sTabread_init(&sTabread_3boll6hd, &hTable_BkpPqQni, false);
  numBytes += sLine_init(&sLine_rGPeCBbO);
  numBytes += sTabwrite_init(&sTabwrite_KCnjTLWG, &hTable_BkpPqQni);
  numBytes += sTabwrite_init(&sTabwrite_pxiBbMhF, &hTable_kCggm0SS);
  numBytes += sLine_init(&sLine_s4B6tdZE);
  numBytes += sPhasor_k_init(&sPhasor_eQBLPEE1, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_X2SPExBU);
  numBytes += sRPole_init(&sRPole_kRw3wPos);
  numBytes += sRPole_init(&sRPole_NW8eAYDd);
  numBytes += sTabhead_init(&sTabhead_yEmEXCFR, &hTable_GYN2Aky9);
  numBytes += sTabread_init(&sTabread_8xhgTnsJ, &hTable_GYN2Aky9, false);
  numBytes += sTabread_init(&sTabread_2NrVyT9I, &hTable_GYN2Aky9, false);
  numBytes += sLine_init(&sLine_klPNvaUU);
  numBytes += sTabhead_init(&sTabhead_uoYMILOs, &hTable_Xo7Z9t0p);
  numBytes += sTabread_init(&sTabread_d8C9FCcU, &hTable_Xo7Z9t0p, false);
  numBytes += sTabread_init(&sTabread_I1mzJgVO, &hTable_Xo7Z9t0p, false);
  numBytes += sLine_init(&sLine_Hl2BfCPM);
  numBytes += sTabwrite_init(&sTabwrite_Sv6mGyRg, &hTable_Xo7Z9t0p);
  numBytes += sTabwrite_init(&sTabwrite_ru4L2EBX, &hTable_GYN2Aky9);
  numBytes += cVar_init_f(&cVar_wtgpdLqU, 0.0f);
  numBytes += cVar_init_f(&cVar_sMGatU7M, 0.0f);
  numBytes += cVar_init_f(&cVar_W4HWb10L, 0.0f);
  numBytes += cVar_init_f(&cVar_PWEkPoB1, 0.0f);
  numBytes += cSlice_init(&cSlice_6xyqthrZ, 1, -1);
  numBytes += cVar_init_f(&cVar_ouvaGJcO, 1337.0f);
  numBytes += cVar_init_f(&cVar_Y2qN3WzS, 0.0f);
  numBytes += cIf_init(&cIf_aHLUowVX, false);
  numBytes += cIf_init(&cIf_1Nl12AuG, false);
  numBytes += cBinop_init(&cBinop_bxFCbvkC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_1tixb7XF, false);
  numBytes += cBinop_init(&cBinop_CATBLcYm, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_zzLoXDgy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_FGLI9iF6, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_S5MFS31A, 0.0f);
  numBytes += cIf_init(&cIf_ClL7ou3C, false);
  numBytes += cIf_init(&cIf_r21iuROp, false);
  numBytes += cBinop_init(&cBinop_Q2LQjxIi, 0.0f); // __pow
  numBytes += cIf_init(&cIf_GaZ4mAE5, false);
  numBytes += cBinop_init(&cBinop_rCkhlnK3, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ZefllewM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8sMHkBrO, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_4blRqV5Q, 0.0f);
  numBytes += cIf_init(&cIf_WwtozUCA, false);
  numBytes += cIf_init(&cIf_zZ2j1Qe4, false);
  numBytes += cBinop_init(&cBinop_uPvg9SNn, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aFJtFfvj, false);
  numBytes += cBinop_init(&cBinop_WYSixzNS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_O3CJVwwJ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Qx6f5oQ1, -15.0f); // __eq
  numBytes += cIf_init(&cIf_PZ5C3of7, false);
  numBytes += cSlice_init(&cSlice_wyOf1ivz, 1, -1);
  numBytes += cVar_init_f(&cVar_qokbJz24, 0.0f);
  numBytes += cSlice_init(&cSlice_LCHkkhHZ, 1, -1);
  numBytes += cVar_init_f(&cVar_CJGlTnj0, 0.0f);
  numBytes += cSlice_init(&cSlice_bPmh7egA, 1, -1);
  numBytes += cVar_init_f(&cVar_mDUe8qka, 0.0f);
  numBytes += cSlice_init(&cSlice_r9Li1Oh4, 1, -1);
  numBytes += cVar_init_f(&cVar_1kjYOVNu, 0.313f);
  numBytes += cBinop_init(&cBinop_gQlSK6V4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_9S8NyFAZ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_cM3xUD3N, 0.0f);
  numBytes += cVar_init_f(&cVar_X2PvYgnA, 1337.0f);
  numBytes += cVar_init_f(&cVar_EpZWGAb6, 0.3f);
  numBytes += cBinop_init(&cBinop_ZgIBhIwO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZfdeOqtA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ELu7jRIm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1EF74fZ0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ftfcuh6V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7QOIyJ2C, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U39nj0Ba, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_gNskKxoD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_eNdgwC9q, 0.0f);
  numBytes += cVar_init_f(&cVar_sssQKNeL, 1337.0f);
  numBytes += cVar_init_f(&cVar_Vu80HSBq, 0.313f);
  numBytes += cBinop_init(&cBinop_o8HSPufw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VDcdC9Hh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_23RbIFz2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rRT3nVKK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RmTVfOmJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rFzviye1, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_LzmAIMoC, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_euonMSGY, 0.0f);
  numBytes += cVar_init_f(&cVar_RVjr0zRQ, 1037.0f);
  numBytes += cVar_init_f(&cVar_vxi3flPf, 0.4f);
  numBytes += cBinop_init(&cBinop_0bFYB3t9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KoPI50gO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k3V3mHm4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_A3FlqJzI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ktnK8KtJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aURNiLuN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5vo1R0T3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ibfFNT0o, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fV8WkFqc, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_svqHcSiH, 1, -1);
  numBytes += cVar_init_f(&cVar_qxNJPTSN, 1337.0f);
  numBytes += cVar_init_f(&cVar_QkHmH2tF, 0.0f);
  numBytes += cIf_init(&cIf_SKQMJCmK, false);
  numBytes += cIf_init(&cIf_L5Nte7Dk, false);
  numBytes += cBinop_init(&cBinop_MWCQEHw7, 0.0f); // __pow
  numBytes += cIf_init(&cIf_AAV8NwSZ, false);
  numBytes += cBinop_init(&cBinop_qhKbMk2w, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_jhjqHEuK, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_YJrGEN0z, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_R7eSTPqx, 0.0f);
  numBytes += cIf_init(&cIf_ATYqrkVJ, false);
  numBytes += cIf_init(&cIf_GtAwdvKO, false);
  numBytes += cBinop_init(&cBinop_y1vh5XWC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_YoSgKns3, false);
  numBytes += cBinop_init(&cBinop_DeYpuimI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_EahDhkqV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_zwWkGkas, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_rrtRN31k, 0.0f);
  numBytes += cIf_init(&cIf_UMyeaiXh, false);
  numBytes += cIf_init(&cIf_iiXoKnDs, false);
  numBytes += cBinop_init(&cBinop_V3UU1dKv, 0.0f); // __pow
  numBytes += cIf_init(&cIf_U8ySpv9Z, false);
  numBytes += cBinop_init(&cBinop_Lp1nfAsM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_X8Qoj5bK, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UyLPoOdL, -15.0f); // __eq
  numBytes += cIf_init(&cIf_nm8yX6rX, false);
  numBytes += cSlice_init(&cSlice_v7QYt3XN, 1, -1);
  numBytes += cVar_init_f(&cVar_SWiE0Wif, 0.0f);
  numBytes += cSlice_init(&cSlice_jY9WpuJv, 1, -1);
  numBytes += cVar_init_f(&cVar_cwAmP1iJ, 0.0f);
  numBytes += cSlice_init(&cSlice_nQlM2aQl, 1, -1);
  numBytes += cVar_init_f(&cVar_WRk1VsD8, 0.0f);
  numBytes += cSlice_init(&cSlice_5Y6tAPkf, 1, -1);
  numBytes += cVar_init_f(&cVar_WCf62iS9, 0.313f);
  numBytes += cBinop_init(&cBinop_v6qNTAEV, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_rDB5wEfr, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1TuqpWRG, 0.0f);
  numBytes += cVar_init_f(&cVar_AoDJzqBA, 1337.0f);
  numBytes += cVar_init_f(&cVar_WAFcPxOM, 0.3f);
  numBytes += cBinop_init(&cBinop_mdzOhjcV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5pDrCAai, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oyt3aBoN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Gi8C2oZF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cDtN112B, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OdqibqaS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1pPliu3w, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_OuwsbMdF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MrkzgaNt, 0.0f);
  numBytes += cVar_init_f(&cVar_1UepeG6k, 1337.0f);
  numBytes += cVar_init_f(&cVar_MngwFbvN, 0.313f);
  numBytes += cBinop_init(&cBinop_dsCkOFmO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SAENSLz0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vnossdHu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2iiv8xpZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LM0RTK2w, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Fc1bDPxY, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_cIMrIf1f, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_OaAbhd5C, 0.0f);
  numBytes += cVar_init_f(&cVar_AAP8hLw4, 1037.0f);
  numBytes += cVar_init_f(&cVar_pincZ4l0, 0.4f);
  numBytes += cBinop_init(&cBinop_KsjXej8X, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9KDIzazr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Fbqpx9tY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Zumov2qW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vlZnbfCJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Jn9DwjL1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_nDd1nS4G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JKjxJPpV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BGWe4SNr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KKEBxXzU, 5705.6f);
  numBytes += cVar_init_f(&cVar_PXN2lSuT, 313.3f);
  numBytes += cBinop_init(&cBinop_IfS23KX8, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_3NMpk8gg, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Vw3iY12s, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_3EOk7sDA, 0.0f);
  numBytes += cVar_init_f(&cVar_hgKWrsox, 0.0f);
  numBytes += cVar_init_f(&cVar_yC0kwlHy, 0.0f);
  numBytes += cVar_init_f(&cVar_sRuVjGyj, 0.0f);
  numBytes += cVar_init_f(&cVar_7G0My9hB, 0.0f);
  numBytes += cVar_init_f(&cVar_ZT9NibBe, 0.0f);
  numBytes += cVar_init_f(&cVar_AjtDq3fy, 0.0f);
  numBytes += cVar_init_f(&cVar_UU0SainA, 0.0f);
  numBytes += cVar_init_f(&cVar_M77yGMhO, 0.0f);
  numBytes += cVar_init_f(&cVar_3evq9t8A, 0.0f);
  numBytes += cVar_init_f(&cVar_tPZ7nUCF, 0.0f);
  numBytes += cVar_init_f(&cVar_Nqw6WoQm, 0.0f);
  numBytes += cVar_init_s(&cVar_mKbGJRZB, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_p3igAnY2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sV6X7RHD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cqKbcPsX, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_vOmCoXr2, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_3umjQUni, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_blIDUBlE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hmAX9mia, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_gEwfT7Wh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UWMjdx2t, 0.0f);
  numBytes += hTable_init(&hTable_vugnvzdv, 256);
  numBytes += cDelay_init(this, &cDelay_q2pfYmve, 0.0f);
  numBytes += cDelay_init(this, &cDelay_aVWfostF, 0.0f);
  numBytes += hTable_init(&hTable_ZMm5JoFr, 256);
  numBytes += cVar_init_f(&cVar_bLesO6Xc, 14.0f);
  numBytes += cBinop_init(&cBinop_LLOGodlH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_IQM4JsJ6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FuAzozEr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_YWzVC7Ij, 14.0f);
  numBytes += cBinop_init(&cBinop_IPbQARMo, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_SEvY4NEY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ku0Pyl5j, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Wlh1i79R, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_4DWvNdl6, 1, -1);
  numBytes += cVar_init_f(&cVar_0gXsmoVI, 0.2f);
  numBytes += cSlice_init(&cSlice_VIx4OAHW, 1, -1);
  numBytes += cVar_init_f(&cVar_LBKYOGL9, 0.0f);
  numBytes += cSlice_init(&cSlice_mxjrLtnL, 1, -1);
  numBytes += cVar_init_f(&cVar_5RLErKEh, 2.0f);
  numBytes += cSlice_init(&cSlice_q2fdni5U, 1, -1);
  numBytes += cVar_init_f(&cVar_RovbXoLN, 0.5f);
  numBytes += cVar_init_s(&cVar_Zk4K6euJ, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_CZA3HfAf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lk8QE2fb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XRCbU3um, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_5uacf59a, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_7OUNq3t5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OAQsQDpr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3dYf257f, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_rcm47hVS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_K4vogKjL, 0.0f);
  numBytes += hTable_init(&hTable_BkpPqQni, 256);
  numBytes += cDelay_init(this, &cDelay_BXgVdReF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9S7aFLUD, 0.0f);
  numBytes += hTable_init(&hTable_kCggm0SS, 256);
  numBytes += cVar_init_f(&cVar_u6amFfRW, 14.0f);
  numBytes += cBinop_init(&cBinop_TwNeZLkU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lZTmoLyf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EuSVaxHF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ZTDYFtym, 14.0f);
  numBytes += cBinop_init(&cBinop_Lnv3f0H3, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_8pz8pGUv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GAnhxXuw, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_gFjDoEQY, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_PPuNlCrY, 1, -1);
  numBytes += cVar_init_f(&cVar_NXjniUWF, 0.2f);
  numBytes += cSlice_init(&cSlice_fGFRfInM, 1, -1);
  numBytes += cVar_init_f(&cVar_Y5CM0pqI, 0.0f);
  numBytes += cSlice_init(&cSlice_bvbFfpw5, 1, -1);
  numBytes += cVar_init_f(&cVar_GRaXrEda, 2.0f);
  numBytes += cSlice_init(&cSlice_HaQdasXf, 1, -1);
  numBytes += cVar_init_f(&cVar_rhZHTzW5, 0.5f);
  numBytes += cVar_init_s(&cVar_uE9t7Tqi, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_Utu5qY8F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5hmgaPpr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Gyp2w2xF, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_s4RFkkwY, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_kmdpicXe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OvgxkEYh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sr9MCtHE, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_FG7vWTVw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_jZtAK5GF, 0.0f);
  numBytes += hTable_init(&hTable_Xo7Z9t0p, 256);
  numBytes += cDelay_init(this, &cDelay_K2wcR8pJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_AWPQzbQv, 0.0f);
  numBytes += hTable_init(&hTable_GYN2Aky9, 256);
  numBytes += cVar_init_f(&cVar_PEoJeEDj, 14.0f);
  numBytes += cBinop_init(&cBinop_aKEvWSDO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_iXYq3yXm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZYHkapsm, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jbJnrXMA, 14.0f);
  numBytes += cBinop_init(&cBinop_ydnNL0gQ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_8kaEyKTA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gyhsXw1Z, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_U3jGiZKY, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_4SFTlRKa, 1, -1);
  numBytes += cVar_init_f(&cVar_snKIjiii, 0.2f);
  numBytes += cSlice_init(&cSlice_6hBq2Bv8, 1, -1);
  numBytes += cVar_init_f(&cVar_hIFIiQgU, 0.0f);
  numBytes += cSlice_init(&cSlice_1GFy6nUT, 1, -1);
  numBytes += cVar_init_f(&cVar_Fm11njv5, 2.0f);
  numBytes += cSlice_init(&cSlice_Ed0FRZvw, 1, -1);
  numBytes += cVar_init_f(&cVar_x4msGgmD, 0.5f);
  numBytes += sVarf_init(&sVarf_TUTuWxc3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_clrm3RN9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K7JCyqup, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Txpx3K0b, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DeDLDalo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0XDXbL1u, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_vugnvzdv);
  hTable_free(&hTable_ZMm5JoFr);
  hTable_free(&hTable_BkpPqQni);
  hTable_free(&hTable_kCggm0SS);
  hTable_free(&hTable_Xo7Z9t0p);
  hTable_free(&hTable_GYN2Aky9);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_vugnvzdv; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_ZMm5JoFr; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_BkpPqQni; // del-1397-flanger-r
    case 0x578173CB: return &hTable_kCggm0SS; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_Xo7Z9t0p; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_GYN2Aky9; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zv954Atj_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a1zMSSoB_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kBnOrwPN_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PXIKBCru_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ppaQAD4x_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QhRdmFCN_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PIPbiKby_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sIPmI9bC_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6zFHfULs_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_13i1aztm_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6uCDituw_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fuNzNeV1_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UfgJ2HtZ_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G3Z303EU_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LjeYSgFN_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tmbNtN3M_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qXe6JI7O_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qdWd8rUt_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0LpEIeH8_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x9GYn4Hi_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5RtPfQdF_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BdGzYj0t_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uItSXrmb_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eilDs5Qi_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rNbvffxH_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tTcUsQA9_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D5NigflJ_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aigRTZCP_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VFk3yPIy_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eDC95jbX_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e0LSqNrG_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5e7LBvPM_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ruWcj7Se_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dl6ytt0i_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Idb7CuEw_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bRX01jil_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FMymMqIG_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hmQns5Az_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U3TbIwKH_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mWePdMKU_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4myPhqcC_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jOCiZjVX_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_83l9hmek_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vkrPsDqY_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eLv9h83T_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kuwp9psa_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mjDXy6SG_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Fql7Q01p_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DjcUH9qq_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AFNFBjci_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XxnU5tLP_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_11DaGyjT_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o0y4xfeX_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WNiXTHQV_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xzDzcc3C_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2sD1Duq1_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iLSUFGQW_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_wtgpdLqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5MFblaR3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_sMGatU7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xmtPmVEi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_W4HWb10L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4or0Dq3n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_PWEkPoB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PbRETR20_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SPsIo6Sz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_alb0ulip_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TKVjAiJ0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_e4bjaiFF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6xyqthrZ, 0, m, &cSlice_6xyqthrZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_K3BSYlgm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_6xyqthrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XPW4L36M_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XPW4L36M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ouvaGJcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XPW4L36M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_XPW4L36M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0LpEIeH8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Y2qN3WzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_57EzqdZW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_aHLUowVX, 0, m, &cIf_aHLUowVX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_aHLUowVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QqPLC9WD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_1Nl12AuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_0qEjRGWZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_SWeuEgDx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_lGpljhp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bxFCbvkC, HV_BINOP_POW, 0, m, &cBinop_bxFCbvkC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bxFCbvkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1tixb7XF, 0, m, &cIf_1tixb7XF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3fJxezSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_LSycLA6h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zrYzZg04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1Nl12AuG, 0, m, &cIf_1Nl12AuG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QM4DFy7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_humHRBPx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_humHRBPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1Nl12AuG, 1, m, &cIf_1Nl12AuG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SWeuEgDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_3fJxezSW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0qEjRGWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_1tixb7XF, 0, m, &cIf_1tixb7XF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LSycLA6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bxFCbvkC, HV_BINOP_POW, 1, m, &cBinop_bxFCbvkC_sendMessage);
  cMsg_lGpljhp7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_1tixb7XF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_5vo1R0T3, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_57EzqdZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHLUowVX, 1, m, &cIf_aHLUowVX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QqPLC9WD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zzLoXDgy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_zzLoXDgy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FGLI9iF6, HV_BINOP_EQ, 1, m, &cBinop_FGLI9iF6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yOPHUKu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CATBLcYm, HV_BINOP_ADD, 0, m, &cBinop_CATBLcYm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CATBLcYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QM4DFy7l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zrYzZg04_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zzLoXDgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1tixb7XF, 1, m, &cIf_1tixb7XF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FGLI9iF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kiAkGdWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_kiAkGdWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5vo1R0T3, m);
}

void Heavy_WSTD_FL3NGR::cCast_y7kk7gUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yOPHUKu0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_GBsopdXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y2qN3WzS, 0, m, &cVar_Y2qN3WzS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZTyjpUdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CATBLcYm, HV_BINOP_ADD, 1, m, &cBinop_CATBLcYm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zzLoXDgy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_zzLoXDgy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FGLI9iF6, HV_BINOP_EQ, 0, m, &cBinop_FGLI9iF6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_S5MFS31A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GRoySK4b_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ClL7ou3C, 0, m, &cIf_ClL7ou3C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ClL7ou3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9yQOI4ya_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_r21iuROp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CVjonLhp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_KDPNl3fn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_e3k9yjND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q2LQjxIi, HV_BINOP_POW, 0, m, &cBinop_Q2LQjxIi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q2LQjxIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GaZ4mAE5, 0, m, &cIf_GaZ4mAE5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_63yAzJxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_i6I3anBn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IABwPgsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r21iuROp, 0, m, &cIf_r21iuROp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YeEZlvS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UUtW2UY4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UUtW2UY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r21iuROp, 1, m, &cIf_r21iuROp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KDPNl3fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_63yAzJxj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CVjonLhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_GaZ4mAE5, 0, m, &cIf_GaZ4mAE5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i6I3anBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q2LQjxIi, HV_BINOP_POW, 1, m, &cBinop_Q2LQjxIi_sendMessage);
  cMsg_e3k9yjND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_GaZ4mAE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Kn37DfDt_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_39hxuBwX_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_0JdDQgrz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_GRoySK4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ClL7ou3C, 1, m, &cIf_ClL7ou3C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9yQOI4ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZefllewM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZefllewM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8sMHkBrO, HV_BINOP_EQ, 1, m, &cBinop_8sMHkBrO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rCWM2VtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rCkhlnK3, HV_BINOP_ADD, 0, m, &cBinop_rCkhlnK3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rCkhlnK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YeEZlvS5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IABwPgsh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZefllewM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GaZ4mAE5, 1, m, &cIf_GaZ4mAE5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8sMHkBrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_trQfdwpu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_trQfdwpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Kn37DfDt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_39hxuBwX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_0JdDQgrz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zEDzXL4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rCWM2VtF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_xT7kM7ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rCkhlnK3, HV_BINOP_ADD, 1, m, &cBinop_rCkhlnK3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZefllewM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZefllewM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8sMHkBrO, HV_BINOP_EQ, 0, m, &cBinop_8sMHkBrO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8Hdpp1U1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S5MFS31A, 0, m, &cVar_S5MFS31A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_4blRqV5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Y2Hk1rda_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_WwtozUCA, 0, m, &cIf_WwtozUCA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_WwtozUCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MCoAombS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_zZ2j1Qe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kF65xhya_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ozoWDpCa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_klUOAnN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uPvg9SNn, HV_BINOP_POW, 0, m, &cBinop_uPvg9SNn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uPvg9SNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aFJtFfvj, 0, m, &cIf_aFJtFfvj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uYF04VHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_YIicEOD7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_h55EFAY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zZ2j1Qe4, 0, m, &cIf_zZ2j1Qe4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GHFhODdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gB4gEBTI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gB4gEBTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zZ2j1Qe4, 1, m, &cIf_zZ2j1Qe4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ozoWDpCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uYF04VHj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kF65xhya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aFJtFfvj, 0, m, &cIf_aFJtFfvj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YIicEOD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uPvg9SNn, HV_BINOP_POW, 1, m, &cBinop_uPvg9SNn_sendMessage);
  cMsg_klUOAnN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_aFJtFfvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_fV8WkFqc, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_Y2Hk1rda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WwtozUCA, 1, m, &cIf_WwtozUCA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MCoAombS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O3CJVwwJ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_O3CJVwwJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qx6f5oQ1, HV_BINOP_EQ, 1, m, &cBinop_Qx6f5oQ1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_js7AVSjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WYSixzNS, HV_BINOP_ADD, 0, m, &cBinop_WYSixzNS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WYSixzNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GHFhODdf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h55EFAY6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_O3CJVwwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aFJtFfvj, 1, m, &cIf_aFJtFfvj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qx6f5oQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZXuehiag_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ZXuehiag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fV8WkFqc, m);
}

void Heavy_WSTD_FL3NGR::cCast_vr40PKPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_js7AVSjY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_eYnUKF4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WYSixzNS, HV_BINOP_ADD, 1, m, &cBinop_WYSixzNS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O3CJVwwJ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_O3CJVwwJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qx6f5oQ1, HV_BINOP_EQ, 0, m, &cBinop_Qx6f5oQ1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sW6mF9m0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4blRqV5Q, 0, m, &cVar_4blRqV5Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_PZ5C3of7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_ibfFNT0o, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_mXq1OdM1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wyOf1ivz, 0, m, &cSlice_wyOf1ivz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VsiCdcJj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_wyOf1ivz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vKZefadu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vKZefadu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_qokbJz24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vKZefadu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_vKZefadu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qXe6JI7O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_VsiCdcJj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LCHkkhHZ, 0, m, &cSlice_LCHkkhHZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_e4bjaiFF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_LCHkkhHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_m5dEX73Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_m5dEX73Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_CJGlTnj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m5dEX73Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_m5dEX73Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5RtPfQdF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_K3BSYlgm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bPmh7egA, 0, m, &cSlice_bPmh7egA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZgfSbk52_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_bPmh7egA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SnffsKpp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SnffsKpp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_mDUe8qka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SnffsKpp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SnffsKpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qdWd8rUt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ZgfSbk52_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r9Li1Oh4, 0, m, &cSlice_r9Li1Oh4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_r9Li1Oh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ixQWIM5f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ixQWIM5f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_1kjYOVNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ixQWIM5f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ixQWIM5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_x9GYn4Hi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_UjVhXouO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UyBlHbGN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YtRn1dvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GfSDgodm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JbEeeFRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jcsi5RKj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_DFC6vOzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8mDJExTU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sXeBCcnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yOqAnyen, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rquFqQbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uIy0OWsx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_uIy0OWsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQlSK6V4, HV_BINOP_DIVIDE, 1, m, &cBinop_gQlSK6V4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CyZs6ZzB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_M8wVz3q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_rPudBypM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vNLEEwuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_M8wVz3q2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rPudBypM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQlSK6V4, HV_BINOP_DIVIDE, 0, m, &cBinop_gQlSK6V4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CyZs6ZzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vNLEEwuL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gQlSK6V4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9S8NyFAZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_9S8NyFAZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9S8NyFAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1COtW9mW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XSHW6FRB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_dtXIuvBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w7MBMWQ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_AmydZFGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9vgOLAx4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4APtF3gN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_zLmpNpQG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zLmpNpQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9S8NyFAZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_9S8NyFAZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_47E6PBuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qDqT3UWo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qDqT3UWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Oqt53DYm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8rXvUaPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cM3xUD3N, 1, m, &cVar_cM3xUD3N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_cM3xUD3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vUEMUSkQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zSkgfm1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZfdeOqtA, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZfdeOqtA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tmTd1PAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zSkgfm1G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OedZErCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lKVYXC7z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lKVYXC7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ELu7jRIm, HV_BINOP_MULTIPLY, 1, m, &cBinop_ELu7jRIm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6j4Wp81Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1EF74fZ0, HV_BINOP_MULTIPLY, 1, m, &cBinop_1EF74fZ0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ailp3a7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6j4Wp81Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Khz7nlGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ftfcuh6V, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ftfcuh6V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kkCJ8v9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_93wuWFFi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_93wuWFFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7QOIyJ2C, HV_BINOP_MULTIPLY, 1, m, &cBinop_7QOIyJ2C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_X2PvYgnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wFqVMyTp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_4APtF3gN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RkcXrOlv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_EpZWGAb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_47E6PBuF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XSHW6FRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_AmydZFGp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1COtW9mW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_dtXIuvBb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_w7MBMWQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eilDs5Qi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_9vgOLAx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uItSXrmb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_loEgZAjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BdGzYj0t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Oqt53DYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_I2CZJMW3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I2CZJMW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZgIBhIwO, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZgIBhIwO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZgIBhIwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RBhMAOKV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RBhMAOKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_loEgZAjJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vUEMUSkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Tg1in0CK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Tg1in0CK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_djTiyPc0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zsgrohrN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YvdYUUuq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dvQmvXgY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_43ZqHqzo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i2j0XLdu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZfdeOqtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UjVhXouO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ELu7jRIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YtRn1dvE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1EF74fZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JbEeeFRg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ftfcuh6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DFC6vOzj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7QOIyJ2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sXeBCcnX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_YUtIiuqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X2PvYgnA, 0, m, &cVar_X2PvYgnA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_X7HsAP8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EpZWGAb6, 1, m, &cVar_EpZWGAb6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_djTiyPc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_dvQmvXgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1EF74fZ0, HV_BINOP_MULTIPLY, 0, m, &cBinop_1EF74fZ0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_43ZqHqzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ELu7jRIm, HV_BINOP_MULTIPLY, 0, m, &cBinop_ELu7jRIm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_i2j0XLdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZfdeOqtA, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZfdeOqtA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zsgrohrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7QOIyJ2C, HV_BINOP_MULTIPLY, 0, m, &cBinop_7QOIyJ2C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YvdYUUuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ftfcuh6V, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ftfcuh6V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RkcXrOlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cM3xUD3N, 0, m, &cVar_cM3xUD3N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wFqVMyTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EpZWGAb6, 0, m, &cVar_EpZWGAb6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XyEfZ6wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KgWWoASw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_I65xfIRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HNBfDR7m, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_csT0dm5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_041Y24p5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BmWSzfpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3ZS4U94s, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ETSv5PZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5xm5c9kY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_5xm5c9kY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U39nj0Ba, HV_BINOP_DIVIDE, 1, m, &cBinop_U39nj0Ba_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UEtIRn0s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_4bclebNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_xqwZygBf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tmNpN81N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_4bclebNF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xqwZygBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U39nj0Ba, HV_BINOP_DIVIDE, 0, m, &cBinop_U39nj0Ba_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UEtIRn0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tmNpN81N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_U39nj0Ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNskKxoD, HV_BINOP_MULTIPLY, 1, m, &cBinop_gNskKxoD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gNskKxoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ATmexl2E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1KJRbATl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_TYStDoCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BeOb4lbG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_ETaLFboq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IyWyWRRJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bWiMha5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_VFAjgpZS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VFAjgpZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNskKxoD, HV_BINOP_MULTIPLY, 0, m, &cBinop_gNskKxoD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_e04mP3ZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_BHw8NI59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BHw8NI59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A0gVLAjM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BZtR1L8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_23RbIFz2, HV_BINOP_MULTIPLY, 1, m, &cBinop_23RbIFz2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lz649KoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eNdgwC9q, 1, m, &cVar_eNdgwC9q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CoZKQYzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rRT3nVKK, HV_BINOP_MULTIPLY, 1, m, &cBinop_rRT3nVKK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HTOQoFFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mNQ9ZlUG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mNQ9ZlUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RmTVfOmJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_RmTVfOmJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_eNdgwC9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ZD12Poj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_sssQKNeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tcmNb2ss_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bWiMha5X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ivyEzezo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Vu80HSBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_e04mP3ZV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ATmexl2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_TYStDoCa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1KJRbATl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ETaLFboq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_BeOb4lbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_D5NigflJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_IyWyWRRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tTcUsQA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SJC4wbZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rNbvffxH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_A0gVLAjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aajVumCn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aajVumCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o8HSPufw, HV_BINOP_MULTIPLY, 1, m, &cBinop_o8HSPufw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_o8HSPufw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2hxHkAC7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2hxHkAC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SJC4wbZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_4ZD12Poj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LJOEbAoE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LJOEbAoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GrmEtj5o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6P8MOLlR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sxWgz4Hu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5gVETOTx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VDcdC9Hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XyEfZ6wy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_23RbIFz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I65xfIRD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rRT3nVKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_csT0dm5S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RmTVfOmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BmWSzfpj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_yQqLnF51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vu80HSBq, 1, m, &cVar_Vu80HSBq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Z82hl4Lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sssQKNeL, 0, m, &cVar_sssQKNeL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ivyEzezo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eNdgwC9q, 0, m, &cVar_eNdgwC9q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tcmNb2ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vu80HSBq, 0, m, &cVar_Vu80HSBq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5gVETOTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VDcdC9Hh, HV_BINOP_MULTIPLY, 0, m, &cBinop_VDcdC9Hh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sxWgz4Hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_23RbIFz2, HV_BINOP_MULTIPLY, 0, m, &cBinop_23RbIFz2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6P8MOLlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rRT3nVKK, HV_BINOP_MULTIPLY, 0, m, &cBinop_rRT3nVKK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GrmEtj5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RmTVfOmJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_RmTVfOmJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wtvgycbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zqRGVldx, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6CovfwVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_55e7LEFj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6pW5d84x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I6iQ5Dl1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_CfOEChIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f0jLkSE3, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HsqOT9wU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0EPEu8zM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zZepVInM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rZXtKWrx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_rZXtKWrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rFzviye1, HV_BINOP_DIVIDE, 1, m, &cBinop_rFzviye1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_asIVGHRC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_3p6kqFHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_WyGCT6c8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_je2Xn9YC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3p6kqFHq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WyGCT6c8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rFzviye1, HV_BINOP_DIVIDE, 0, m, &cBinop_rFzviye1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_asIVGHRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_je2Xn9YC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rFzviye1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LzmAIMoC, HV_BINOP_MULTIPLY, 1, m, &cBinop_LzmAIMoC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LzmAIMoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rkdSHtyo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wxQhhGXm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_OOsflXMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0LHDlAsL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_l3J0Xm9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kRTYgkWS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ip9m7zA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_iJuefTJf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iJuefTJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LzmAIMoC, HV_BINOP_MULTIPLY, 0, m, &cBinop_LzmAIMoC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P1NmEHG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_HFYhZZix_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HFYhZZix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aNqRYgUk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CZO2VexI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KoPI50gO, HV_BINOP_MULTIPLY, 1, m, &cBinop_KoPI50gO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ULMQJRnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_t71bHRQ3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_t71bHRQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CZO2VexI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_N5iEwMRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iQDPu957_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iQDPu957_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3V3mHm4, HV_BINOP_MULTIPLY, 1, m, &cBinop_k3V3mHm4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rXN9w6BH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3FlqJzI, HV_BINOP_MULTIPLY, 1, m, &cBinop_A3FlqJzI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ImWY7qvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZPA5BRZ6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZPA5BRZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rXN9w6BH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mgxMfmlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_euonMSGY, 1, m, &cVar_euonMSGY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PCkWkO7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktnK8KtJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_ktnK8KtJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CoH9EiVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cjcerbmT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cjcerbmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aURNiLuN, HV_BINOP_MULTIPLY, 1, m, &cBinop_aURNiLuN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_euonMSGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BlHd7Nid_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_RVjr0zRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CvDaQ3ml_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Ip9m7zA5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jTIJjiI1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_vxi3flPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_P1NmEHG2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rkdSHtyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_OOsflXMN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wxQhhGXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_l3J0Xm9X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_0LHDlAsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eDC95jbX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_kRTYgkWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VFk3yPIy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_mSP1PhWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aigRTZCP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aNqRYgUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_exSZcvYG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_exSZcvYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0bFYB3t9, HV_BINOP_MULTIPLY, 1, m, &cBinop_0bFYB3t9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0bFYB3t9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_s25GaWGh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_s25GaWGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mSP1PhWY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BlHd7Nid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4nQinyos_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4nQinyos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Az9uJDTT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1tBCd5Z9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_19atNvfE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eCb2M1FU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a2Kdk7Zb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QYMSuKCC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KoPI50gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wtvgycbm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_k3V3mHm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6CovfwVa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_A3FlqJzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6pW5d84x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ktnK8KtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CfOEChIj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aURNiLuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HsqOT9wU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_aaI98XuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vxi3flPf, 1, m, &cVar_vxi3flPf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_j8qrLGqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RVjr0zRQ, 0, m, &cVar_RVjr0zRQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eCb2M1FU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3FlqJzI, HV_BINOP_MULTIPLY, 0, m, &cBinop_A3FlqJzI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Az9uJDTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_a2Kdk7Zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3V3mHm4, HV_BINOP_MULTIPLY, 0, m, &cBinop_k3V3mHm4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QYMSuKCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KoPI50gO, HV_BINOP_MULTIPLY, 0, m, &cBinop_KoPI50gO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1tBCd5Z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aURNiLuN, HV_BINOP_MULTIPLY, 0, m, &cBinop_aURNiLuN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_19atNvfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktnK8KtJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_ktnK8KtJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CvDaQ3ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vxi3flPf, 0, m, &cVar_vxi3flPf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jTIJjiI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_euonMSGY, 0, m, &cVar_euonMSGY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Kn37DfDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PZ5C3of7, 1, m, &cIf_PZ5C3of7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EBg6HwCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ibfFNT0o, m);
}

void Heavy_WSTD_FL3NGR::cBinop_39hxuBwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EBg6HwCu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0JdDQgrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PZ5C3of7, 0, m, &cIf_PZ5C3of7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_DlhXwy6O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_svqHcSiH, 0, m, &cSlice_svqHcSiH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eEkyd69M_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_svqHcSiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NyJIK7mP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NyJIK7mP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_qxNJPTSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NyJIK7mP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_NyJIK7mP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ruWcj7Se_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_QkHmH2tF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3vrepBZN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SKQMJCmK, 0, m, &cIf_SKQMJCmK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_SKQMJCmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3E6g22ud_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_L5Nte7Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7iZ6ImO9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_nimJG2dR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_HN7fL1Ku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MWCQEHw7, HV_BINOP_POW, 0, m, &cBinop_MWCQEHw7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MWCQEHw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AAV8NwSZ, 0, m, &cIf_AAV8NwSZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dMdZR2HM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_eceGqvcT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_A6gfrAyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L5Nte7Dk, 0, m, &cIf_L5Nte7Dk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Diw4fOnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kbww6sGW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kbww6sGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L5Nte7Dk, 1, m, &cIf_L5Nte7Dk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nimJG2dR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dMdZR2HM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7iZ6ImO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AAV8NwSZ, 0, m, &cIf_AAV8NwSZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eceGqvcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MWCQEHw7, HV_BINOP_POW, 1, m, &cBinop_MWCQEHw7_sendMessage);
  cMsg_HN7fL1Ku_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_AAV8NwSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_nDd1nS4G, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_3vrepBZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SKQMJCmK, 1, m, &cIf_SKQMJCmK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3E6g22ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jhjqHEuK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_jhjqHEuK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YJrGEN0z, HV_BINOP_EQ, 1, m, &cBinop_YJrGEN0z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jPir3bGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qhKbMk2w, HV_BINOP_ADD, 0, m, &cBinop_qhKbMk2w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qhKbMk2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Diw4fOnj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A6gfrAyQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jhjqHEuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AAV8NwSZ, 1, m, &cIf_AAV8NwSZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YJrGEN0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_87x1Cw4H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_87x1Cw4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nDd1nS4G, m);
}

void Heavy_WSTD_FL3NGR::cCast_oSZYS7RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jPir3bGj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_XXUlhwlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qhKbMk2w, HV_BINOP_ADD, 1, m, &cBinop_qhKbMk2w_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jhjqHEuK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_jhjqHEuK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YJrGEN0z, HV_BINOP_EQ, 0, m, &cBinop_YJrGEN0z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MesrYYk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QkHmH2tF, 0, m, &cVar_QkHmH2tF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_R7eSTPqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nBSzH2wN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ATYqrkVJ, 0, m, &cIf_ATYqrkVJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ATYqrkVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8mYKyAls_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_GtAwdvKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_b267J3x9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_pSPVNnZg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_bCFg8JpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y1vh5XWC, HV_BINOP_POW, 0, m, &cBinop_y1vh5XWC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y1vh5XWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YoSgKns3, 0, m, &cIf_YoSgKns3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dBvYu8vB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_YbPUl49y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Inud85iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GtAwdvKO, 0, m, &cIf_GtAwdvKO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_h40euyKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_77iIqZcH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_77iIqZcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GtAwdvKO, 1, m, &cIf_GtAwdvKO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pSPVNnZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dBvYu8vB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_b267J3x9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YoSgKns3, 0, m, &cIf_YoSgKns3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YbPUl49y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y1vh5XWC, HV_BINOP_POW, 1, m, &cBinop_y1vh5XWC_sendMessage);
  cMsg_bCFg8JpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_YoSgKns3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8Y36LM60_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Z8GZVJRE_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_lZg5Zsmt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_nBSzH2wN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ATYqrkVJ, 1, m, &cIf_ATYqrkVJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8mYKyAls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EahDhkqV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_EahDhkqV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zwWkGkas, HV_BINOP_EQ, 1, m, &cBinop_zwWkGkas_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NJNl8cPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DeYpuimI, HV_BINOP_ADD, 0, m, &cBinop_DeYpuimI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DeYpuimI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h40euyKf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Inud85iI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EahDhkqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YoSgKns3, 1, m, &cIf_YoSgKns3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zwWkGkas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BVWOqIQK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BVWOqIQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8Y36LM60_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Z8GZVJRE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_lZg5Zsmt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Q7qkxAuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DeYpuimI, HV_BINOP_ADD, 1, m, &cBinop_DeYpuimI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EahDhkqV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_EahDhkqV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zwWkGkas, HV_BINOP_EQ, 0, m, &cBinop_zwWkGkas_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_96tNTVHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R7eSTPqx, 0, m, &cVar_R7eSTPqx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KFyIF9uW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NJNl8cPv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_rrtRN31k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O3YvW6iH_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_UMyeaiXh, 0, m, &cIf_UMyeaiXh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_UMyeaiXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jik5EB1d_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_iiXoKnDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_yP0KoB1f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_vYfkZBk3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_P5zeHnqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V3UU1dKv, HV_BINOP_POW, 0, m, &cBinop_V3UU1dKv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V3UU1dKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U8ySpv9Z, 0, m, &cIf_U8ySpv9Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8dIbJlrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9Maa7sdn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Yd0fTaXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GVBIn5QD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EvFuW93B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iiXoKnDs, 0, m, &cIf_iiXoKnDs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GVBIn5QD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iiXoKnDs, 1, m, &cIf_iiXoKnDs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vYfkZBk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_8dIbJlrI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yP0KoB1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_U8ySpv9Z, 0, m, &cIf_U8ySpv9Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9Maa7sdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V3UU1dKv, HV_BINOP_POW, 1, m, &cBinop_V3UU1dKv_sendMessage);
  cMsg_P5zeHnqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_U8ySpv9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_BGWe4SNr, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_O3YvW6iH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UMyeaiXh, 1, m, &cIf_UMyeaiXh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jik5EB1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X8Qoj5bK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_X8Qoj5bK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyLPoOdL, HV_BINOP_EQ, 1, m, &cBinop_UyLPoOdL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_neh3dhvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lp1nfAsM, HV_BINOP_ADD, 0, m, &cBinop_Lp1nfAsM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lp1nfAsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yd0fTaXb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EvFuW93B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_X8Qoj5bK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U8ySpv9Z, 1, m, &cIf_U8ySpv9Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UyLPoOdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ej5tB1y3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ej5tB1y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BGWe4SNr, m);
}

void Heavy_WSTD_FL3NGR::cCast_pE2OG9yU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_neh3dhvq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_mnf6eZmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rrtRN31k, 0, m, &cVar_rrtRN31k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_b6orMfcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lp1nfAsM, HV_BINOP_ADD, 1, m, &cBinop_Lp1nfAsM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_X8Qoj5bK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_X8Qoj5bK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyLPoOdL, HV_BINOP_EQ, 0, m, &cBinop_UyLPoOdL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_nm8yX6rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_JKjxJPpV, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_UC3HsCQ9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v7QYt3XN, 0, m, &cSlice_v7QYt3XN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OeV6o0Of_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_v7QYt3XN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WygHa0Qv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WygHa0Qv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_SWiE0Wif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WygHa0Qv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_WygHa0Qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e0LSqNrG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_OeV6o0Of_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jY9WpuJv, 0, m, &cSlice_jY9WpuJv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DlhXwy6O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jY9WpuJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZJz0xlwd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZJz0xlwd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_cwAmP1iJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZJz0xlwd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ZJz0xlwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Idb7CuEw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_eEkyd69M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nQlM2aQl, 0, m, &cSlice_nQlM2aQl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yaVo3h8O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_nQlM2aQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pGqlK24a_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pGqlK24a_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_WRk1VsD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pGqlK24a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_pGqlK24a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5e7LBvPM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_yaVo3h8O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5Y6tAPkf, 0, m, &cSlice_5Y6tAPkf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_5Y6tAPkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JmhKVCzZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JmhKVCzZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_WCf62iS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JmhKVCzZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JmhKVCzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Dl6ytt0i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_51J2A4jU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_omuzDoar, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_d5QgGNUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Knjtg7lq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7Pn72OQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_43cUCiCI, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_lEWUslxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kF9IYD2D, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_b1eUAgpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XBdSMZNu, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Nf6Uk8K6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xkGQYE5S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_xkGQYE5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v6qNTAEV, HV_BINOP_DIVIDE, 1, m, &cBinop_v6qNTAEV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QBEP8Pqy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_OHmOHltD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_W6MkCXia_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SnMSxcxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_OHmOHltD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W6MkCXia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v6qNTAEV, HV_BINOP_DIVIDE, 0, m, &cBinop_v6qNTAEV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QBEP8Pqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SnMSxcxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_v6qNTAEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rDB5wEfr, HV_BINOP_MULTIPLY, 1, m, &cBinop_rDB5wEfr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rDB5wEfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JJtMHxdI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IuEgnRBU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_uL4Q1gsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Vd9QXvsR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_KKl4oq1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G7neqKqv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zHj2AJlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_rmVl9u7g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rmVl9u7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rDB5wEfr, HV_BINOP_MULTIPLY, 0, m, &cBinop_rDB5wEfr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KD3kPRMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_YnSTcwEy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YnSTcwEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NlvaM3lN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qeklXcDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1TuqpWRG, 1, m, &cVar_1TuqpWRG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_1TuqpWRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1ZQsnIgc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_x9YAG8L5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5pDrCAai, HV_BINOP_MULTIPLY, 1, m, &cBinop_5pDrCAai_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J2gWHkhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_x9YAG8L5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7AUEdvgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qAfG9NXV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qAfG9NXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oyt3aBoN, HV_BINOP_MULTIPLY, 1, m, &cBinop_oyt3aBoN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9vywMLkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gi8C2oZF, HV_BINOP_MULTIPLY, 1, m, &cBinop_Gi8C2oZF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NF2KLbwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9vywMLkY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ylwNHvR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cDtN112B, HV_BINOP_MULTIPLY, 1, m, &cBinop_cDtN112B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mbA3hGKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KpwpQ3DL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KpwpQ3DL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OdqibqaS, HV_BINOP_MULTIPLY, 1, m, &cBinop_OdqibqaS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_AoDJzqBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d0dedqDd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_zHj2AJlU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jHWmYQp0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_WAFcPxOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_KD3kPRMH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IuEgnRBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_KKl4oq1k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JJtMHxdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_uL4Q1gsa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_Vd9QXvsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hmQns5Az_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_G7neqKqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FMymMqIG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_AvzdVivn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bRX01jil_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NlvaM3lN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_byvfSJUH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_byvfSJUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mdzOhjcV, HV_BINOP_MULTIPLY, 1, m, &cBinop_mdzOhjcV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mdzOhjcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wUkZg8r2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wUkZg8r2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AvzdVivn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1ZQsnIgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RUPykvd1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RUPykvd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4WPds7GZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iHBEyZ2N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K8nJOoKm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fDrk96dp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ymi9LoJ0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OLyBneON_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5pDrCAai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_51J2A4jU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oyt3aBoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d5QgGNUR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Gi8C2oZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Pn72OQF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cDtN112B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lEWUslxw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OdqibqaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b1eUAgpq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ZChOAP2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AoDJzqBA, 0, m, &cVar_AoDJzqBA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7MqCqeT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WAFcPxOM, 1, m, &cVar_WAFcPxOM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OLyBneON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5pDrCAai, HV_BINOP_MULTIPLY, 0, m, &cBinop_5pDrCAai_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iHBEyZ2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OdqibqaS, HV_BINOP_MULTIPLY, 0, m, &cBinop_OdqibqaS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_K8nJOoKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cDtN112B, HV_BINOP_MULTIPLY, 0, m, &cBinop_cDtN112B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4WPds7GZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_fDrk96dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gi8C2oZF, HV_BINOP_MULTIPLY, 0, m, &cBinop_Gi8C2oZF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ymi9LoJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oyt3aBoN, HV_BINOP_MULTIPLY, 0, m, &cBinop_oyt3aBoN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jHWmYQp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1TuqpWRG, 0, m, &cVar_1TuqpWRG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_d0dedqDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WAFcPxOM, 0, m, &cVar_WAFcPxOM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_o2ZzVnjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8XYj1W8Q, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_OBNnL9Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MvrIKQ1z, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_gfef6gdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4B38cixE, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_avlMK9AZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wuqz9BV6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_lbaqjaJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vKzp5sZ7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_vKzp5sZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1pPliu3w, HV_BINOP_DIVIDE, 1, m, &cBinop_1pPliu3w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dflZcuJV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_oCeECpmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_eOBXNqT2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sQYIDiqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_oCeECpmp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eOBXNqT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1pPliu3w, HV_BINOP_DIVIDE, 0, m, &cBinop_1pPliu3w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dflZcuJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sQYIDiqd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1pPliu3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OuwsbMdF, HV_BINOP_MULTIPLY, 1, m, &cBinop_OuwsbMdF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OuwsbMdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M3RZ8MoB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h6s73VeI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_1bjxClmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tNQLaGjy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_zKaGtoUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oFPZHf2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I5tUOcBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9VVqDMze_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9VVqDMze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OuwsbMdF, HV_BINOP_MULTIPLY, 0, m, &cBinop_OuwsbMdF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VYSD5bcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0ocejDBB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0ocejDBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RWhTqlcs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_n23p2oYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vnossdHu, HV_BINOP_MULTIPLY, 1, m, &cBinop_vnossdHu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pNOUnPeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MrkzgaNt, 1, m, &cVar_MrkzgaNt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PEk0w3Mj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2iiv8xpZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_2iiv8xpZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qS8YHITP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ywgPmQ0N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ywgPmQ0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LM0RTK2w, HV_BINOP_MULTIPLY, 1, m, &cBinop_LM0RTK2w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_MrkzgaNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oHH3du5T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_1UepeG6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VvnwcHgw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_I5tUOcBy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eWyjnbVM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_MngwFbvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VYSD5bcC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_h6s73VeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_zKaGtoUF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_M3RZ8MoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_1bjxClmI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_tNQLaGjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4myPhqcC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oFPZHf2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mWePdMKU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_o4jcN8jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U3TbIwKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RWhTqlcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YCAdFvBP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YCAdFvBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dsCkOFmO, HV_BINOP_MULTIPLY, 1, m, &cBinop_dsCkOFmO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dsCkOFmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PeYfqE1U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PeYfqE1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_o4jcN8jr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_oHH3du5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6wrEFS6Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6wrEFS6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A2gGDT3i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fkq2hosB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WcWJtkWo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bm0yPeVo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SAENSLz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o2ZzVnjT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vnossdHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OBNnL9Po_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2iiv8xpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gfef6gdw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LM0RTK2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_avlMK9AZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ElHCglIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1UepeG6k, 0, m, &cVar_1UepeG6k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PCWqDw6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MngwFbvN, 1, m, &cVar_MngwFbvN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eWyjnbVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MrkzgaNt, 0, m, &cVar_MrkzgaNt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VvnwcHgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MngwFbvN, 0, m, &cVar_MngwFbvN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Fkq2hosB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2iiv8xpZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_2iiv8xpZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_A2gGDT3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LM0RTK2w, HV_BINOP_MULTIPLY, 0, m, &cBinop_LM0RTK2w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Bm0yPeVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SAENSLz0, HV_BINOP_MULTIPLY, 0, m, &cBinop_SAENSLz0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WcWJtkWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vnossdHu, HV_BINOP_MULTIPLY, 0, m, &cBinop_vnossdHu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HkYXTpz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lRWi48u1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kZ5mY5nL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_02MIuWpd, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_I2chzlXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9CpKXfg5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YQhswNzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ojllg8oB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WiGRlAGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r93ah6Ha, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_plTc3mLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_x39itXBn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_x39itXBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fc1bDPxY, HV_BINOP_DIVIDE, 1, m, &cBinop_Fc1bDPxY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mZEIz3FD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_oFseZ1sL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0z4ozlim_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_d2jXGO3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_oFseZ1sL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0z4ozlim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fc1bDPxY, HV_BINOP_DIVIDE, 0, m, &cBinop_Fc1bDPxY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mZEIz3FD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d2jXGO3o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Fc1bDPxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIMrIf1f, HV_BINOP_MULTIPLY, 1, m, &cBinop_cIMrIf1f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cIMrIf1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TTPJFGEM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tuxwQXWS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_yOx2GFcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bt6Jz2KG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_zYhrL1Mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PK5eSjiJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ohiOs8oF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_I04aWuZk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I04aWuZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIMrIf1f, HV_BINOP_MULTIPLY, 0, m, &cBinop_cIMrIf1f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YBLUO3fR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_JTA0m9vZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JTA0m9vZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NX2M2mKC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rJJ5Jz5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9KDIzazr, HV_BINOP_MULTIPLY, 1, m, &cBinop_9KDIzazr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_BBxaaVxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KvMbZqDO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KvMbZqDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rJJ5Jz5R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_no4Ojj8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_P7UnF7L6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P7UnF7L6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fbqpx9tY, HV_BINOP_MULTIPLY, 1, m, &cBinop_Fbqpx9tY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p6UsTNqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zumov2qW, HV_BINOP_MULTIPLY, 1, m, &cBinop_Zumov2qW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YtMni3Tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_m01Z1Pbx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m01Z1Pbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_p6UsTNqF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_keylxOLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OaAbhd5C, 1, m, &cVar_OaAbhd5C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cxbPldlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vlZnbfCJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_vlZnbfCJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AR9WKqP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ROTPernz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ROTPernz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jn9DwjL1, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jn9DwjL1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_OaAbhd5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_anTnpMr8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_AAP8hLw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gb1ZjjiS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ohiOs8oF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jXb7ywE3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_pincZ4l0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_YBLUO3fR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TTPJFGEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_yOx2GFcs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tuxwQXWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_zYhrL1Mx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_bt6Jz2KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vkrPsDqY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_PK5eSjiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_83l9hmek_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Rpbm5fGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jOCiZjVX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NX2M2mKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_D7p3Vy3I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D7p3Vy3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsjXej8X, HV_BINOP_MULTIPLY, 1, m, &cBinop_KsjXej8X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KsjXej8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AM9wGMMa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AM9wGMMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Rpbm5fGW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_anTnpMr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5LSrWBU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5LSrWBU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DJwEAbrX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iFERVXHG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qyb0YdNC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GatV0o6V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uMY8B1br_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yg2Tts0l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9KDIzazr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HkYXTpz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Fbqpx9tY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kZ5mY5nL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Zumov2qW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I2chzlXe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vlZnbfCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YQhswNzg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Jn9DwjL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WiGRlAGT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_70gjj6i4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pincZ4l0, 1, m, &cVar_pincZ4l0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lLqh2Gi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AAP8hLw4, 0, m, &cVar_AAP8hLw4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uMY8B1br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fbqpx9tY, HV_BINOP_MULTIPLY, 0, m, &cBinop_Fbqpx9tY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Yg2Tts0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9KDIzazr, HV_BINOP_MULTIPLY, 0, m, &cBinop_9KDIzazr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iFERVXHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jn9DwjL1, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jn9DwjL1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qyb0YdNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vlZnbfCJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_vlZnbfCJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DJwEAbrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_GatV0o6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zumov2qW, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zumov2qW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gb1ZjjiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pincZ4l0, 0, m, &cVar_pincZ4l0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jXb7ywE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OaAbhd5C, 0, m, &cVar_OaAbhd5C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8Y36LM60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nm8yX6rX, 1, m, &cIf_nm8yX6rX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OEGwjXZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JKjxJPpV, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Z8GZVJRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OEGwjXZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lZg5Zsmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nm8yX6rX, 0, m, &cIf_nm8yX6rX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KKEBxXzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3NMpk8gg, HV_BINOP_DIVIDE, 0, m, &cBinop_3NMpk8gg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_PXN2lSuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IfS23KX8, HV_BINOP_DIVIDE, 1, m, &cBinop_IfS23KX8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3NMpk8gg, HV_BINOP_DIVIDE, 1, m, &cBinop_3NMpk8gg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_DQCyti6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vw3iY12s, HV_BINOP_DIVIDE, 0, m, &cBinop_Vw3iY12s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_AplTC14a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vw3iY12s, HV_BINOP_DIVIDE, 1, m, &cBinop_Vw3iY12s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TKVjAiJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IfS23KX8, HV_BINOP_DIVIDE, 0, m, &cBinop_IfS23KX8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SPsIo6Sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PXN2lSuT, 0, m, &cVar_PXN2lSuT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_alb0ulip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KKEBxXzU, 0, m, &cVar_KKEBxXzU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IfS23KX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_DQCyti6F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3NMpk8gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_AplTC14a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Vw3iY12s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_985UBTPL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_l6sOB0u2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_AWIohSqL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_edGzgNgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_weqnKUvM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_985UBTPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_edGzgNgK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_weqnKUvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_l6sOB0u2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AWIohSqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RnCuHwWI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_3EOk7sDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j7UTXRjn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_hgKWrsox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s33epVpd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_yC0kwlHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O8KcVNKY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_sRuVjGyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KrtHxBmA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_7G0My9hB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MagHOw2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ZT9NibBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oBGQUatg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_AjtDq3fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IA2rgkDL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_UU0SainA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pVa8iJTP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_M77yGMhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JMxTJtPp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_3evq9t8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bkThAcuV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_tPZ7nUCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QdGpmmzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Nqw6WoQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wvZhOhFm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dTGgfe5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_g8jEj65o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g8jEj65o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_JK0yXyOj, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jPMzpPWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MGIYcKBi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_MGIYcKBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_AgktbRdh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_mKbGJRZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fNeTwqZa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_JiUUkE7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YzW6wbu9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_p3igAnY2, m);
}

void Heavy_WSTD_FL3NGR::cBinop_AgktbRdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sV6X7RHD, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fNeTwqZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JiUUkE7q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YzW6wbu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cqKbcPsX, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fKFcYMwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vxCPNKlQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_vxCPNKlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wkaDQ8PT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_vOmCoXr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SEtjwTVI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_30rbXC5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Kg8cMcdr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3umjQUni, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wkaDQ8PT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_blIDUBlE, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SEtjwTVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_30rbXC5O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Kg8cMcdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hmAX9mia, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SFvh2Cs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZPbzp011_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZPbzp011_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_3XodteIn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_1jtHwpMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mRv4gDLi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_fZgrqP4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C8I9SmF4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3XodteIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9jDdp4eT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9jDdp4eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HUOm9hq6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6jm1hH1e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HUOm9hq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aaDyJzzH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6jm1hH1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gEawUQ8Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aaDyJzzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FYmvs1Vb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gEawUQ8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_R4NrCnCW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R4NrCnCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BA1tWFbs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FYmvs1Vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_1jtHwpMJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BA1tWFbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_fZgrqP4Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sGNXmO78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6W5VMnpn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6W5VMnpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z76wGSt4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_L4wpGxFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4lrPObMT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_4lrPObMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_t0AwCXIo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_gEwfT7Wh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gEwfT7Wh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UWMjdx2t, 0, m, &cDelay_UWMjdx2t_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gEwfT7Wh, 0, m, &cDelay_gEwfT7Wh_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JCiXHnIr, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_UWMjdx2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UWMjdx2t, m);
  cMsg_IzpXWism_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_TNH8b1LR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_uubUCWWD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_vIFXDb0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TBn8zsVd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_vugnvzdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kvIkiWtp_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gEwfT7Wh, 2, m, &cDelay_gEwfT7Wh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i4fmLX8S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TBn8zsVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_vugnvzdv, 0, m, &hTable_vugnvzdv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_t0AwCXIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_vIFXDb0d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_IzpXWism_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_vugnvzdv, 0, m, &hTable_vugnvzdv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_i4fmLX8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gEwfT7Wh, 0, m, &cDelay_gEwfT7Wh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kvIkiWtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UWMjdx2t, 2, m, &cDelay_UWMjdx2t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_uubUCWWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JCiXHnIr, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IO3qgFx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_10Z8J47P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_10Z8J47P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VBo8CVgr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_q2pfYmve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q2pfYmve, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aVWfostF, 0, m, &cDelay_aVWfostF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q2pfYmve, 0, m, &cDelay_q2pfYmve_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fxBynssm, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_aVWfostF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aVWfostF, m);
  cMsg_5Icnpb39_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_YMVknYFR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_O0plChIl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_JMsoEW9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x8F0pLA3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_ZMm5JoFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6TXTCbJ1_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q2pfYmve, 2, m, &cDelay_q2pfYmve_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_24Cqt4u4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_x8F0pLA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ZMm5JoFr, 0, m, &hTable_ZMm5JoFr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VBo8CVgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_JMsoEW9P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5Icnpb39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ZMm5JoFr, 0, m, &hTable_ZMm5JoFr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_24Cqt4u4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_q2pfYmve, 0, m, &cDelay_q2pfYmve_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6TXTCbJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_aVWfostF, 2, m, &cDelay_aVWfostF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_O0plChIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fxBynssm, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_bLesO6Xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LLOGodlH, HV_BINOP_MULTIPLY, 0, m, &cBinop_LLOGodlH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7op9gWsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_H00519Cu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_H00519Cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bk2z538f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LLOGodlH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XFTBrMcr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PBEIqCxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LLOGodlH, HV_BINOP_MULTIPLY, 1, m, &cBinop_LLOGodlH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Bk2z538f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PBEIqCxw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XFTBrMcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rYnm6ckn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rYnm6ckn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_86rqjG4A_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FuAzozEr, m);
}

void Heavy_WSTD_FL3NGR::cBinop_86rqjG4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IQM4JsJ6, m);
}

void Heavy_WSTD_FL3NGR::cVar_YWzVC7Ij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IPbQARMo, HV_BINOP_MULTIPLY, 0, m, &cBinop_IPbQARMo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_z7VFwOPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z8LX9Hw1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Z8LX9Hw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cz9WfNAD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IPbQARMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_csE3gOj0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V2uoDZOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IPbQARMo, HV_BINOP_MULTIPLY, 1, m, &cBinop_IPbQARMo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cz9WfNAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V2uoDZOM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_csE3gOj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Dciths50_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Dciths50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UzkrgU4y_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ku0Pyl5j, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UzkrgU4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SEvY4NEY, m);
}

void Heavy_WSTD_FL3NGR::cMsg_z76wGSt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VQsFiIZ6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_aElBJSW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_jP7kBruY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8aKTTzfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_djvRkeQp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fAex0Nbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_aElBJSW9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qo6Yrw30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KFF6J8EW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KFF6J8EW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wlh1i79R, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wlh1i79R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_djvRkeQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_qo6Yrw30_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wlh1i79R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WKQkVrtm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jP7kBruY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wlh1i79R, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wlh1i79R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WKQkVrtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sZVOsb6g, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_84Epnagc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_cbMkpFu1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cbMkpFu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8aKTTzfK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fAex0Nbd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LeRWee74_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4DWvNdl6, 0, m, &cSlice_4DWvNdl6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_u2EUzg5q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4DWvNdl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_g75dNk9T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_g75dNk9T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_0gXsmoVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g75dNk9T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_g75dNk9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kuwp9psa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_u2EUzg5q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VIx4OAHW, 0, m, &cSlice_VIx4OAHW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_T2LA6tTU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_VIx4OAHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3aGF80GU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3aGF80GU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_LBKYOGL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3aGF80GU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_3aGF80GU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eLv9h83T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_T2LA6tTU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mxjrLtnL, 0, m, &cSlice_mxjrLtnL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PstcQHEk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_mxjrLtnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LBwmvCHI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LBwmvCHI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_5RLErKEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LBwmvCHI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LBwmvCHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Fql7Q01p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_PstcQHEk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_q2fdni5U, 0, m, &cSlice_q2fdni5U_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_q2fdni5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FGcoIIzC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FGcoIIzC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_RovbXoLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FGcoIIzC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_FGcoIIzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mjDXy6SG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_mRv4gDLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m22joC8F, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_C8I9SmF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fPy7S1Lw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_8Pcp0cUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WkU4TSe1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WkU4TSe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_7vZAAs1m, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gd0mVNf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YXgq9tXX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YXgq9tXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_m818mEZI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Zk4K6euJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_53OoP0vZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_eb3Mg2sF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_4iQ1MLB6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CZA3HfAf, m);
}

void Heavy_WSTD_FL3NGR::cBinop_m818mEZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lk8QE2fb, m);
}

void Heavy_WSTD_FL3NGR::cMsg_53OoP0vZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eb3Mg2sF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4iQ1MLB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XRCbU3um, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5bx9pg11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_t3KtAATR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_t3KtAATR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qkr2qwYT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_5uacf59a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DLepVWYk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_HZXZYLbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hHRwo89k_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7OUNq3t5, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qkr2qwYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OAQsQDpr, m);
}

void Heavy_WSTD_FL3NGR::cMsg_DLepVWYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HZXZYLbw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hHRwo89k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3dYf257f, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Y9we22PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ckOD79Y0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ckOD79Y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_IiOkmPPT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_haweeBJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GMUagKFR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_MvXX6hBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VWXuTIRH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IiOkmPPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GJ4ZwOjO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GJ4ZwOjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ahTD0CLV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M7D2Z2sl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_M7D2Z2sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MAUWoNL3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ahTD0CLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xrYQQHWk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xrYQQHWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PjIDCYyV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MAUWoNL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WitcPZ6I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WitcPZ6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_73WKmyV6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PjIDCYyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_haweeBJl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_73WKmyV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_MvXX6hBW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Sa7tzn8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MG6lIIkx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MG6lIIkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IlEuDiwV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wHrU4paI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kcKYiiB1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_kcKYiiB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_F65GFG7G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_rcm47hVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rcm47hVS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K4vogKjL, 0, m, &cDelay_K4vogKjL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rcm47hVS, 0, m, &cDelay_rcm47hVS_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KCnjTLWG, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_K4vogKjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K4vogKjL, m);
  cMsg_hvgaqWVT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_PbTE8rUi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_0NG7QYp4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_eigJlyiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KLOZEKPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_BkpPqQni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yVIWcox0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rcm47hVS, 2, m, &cDelay_rcm47hVS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_87oxv6hv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KLOZEKPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_BkpPqQni, 0, m, &hTable_BkpPqQni_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F65GFG7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_eigJlyiP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hvgaqWVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_BkpPqQni, 0, m, &hTable_BkpPqQni_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_87oxv6hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rcm47hVS, 0, m, &cDelay_rcm47hVS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yVIWcox0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_K4vogKjL, 2, m, &cDelay_K4vogKjL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0NG7QYp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KCnjTLWG, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oAH1JsHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uy427xwh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_uy427xwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vHwEZomc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_BXgVdReF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BXgVdReF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9S7aFLUD, 0, m, &cDelay_9S7aFLUD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BXgVdReF, 0, m, &cDelay_BXgVdReF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pxiBbMhF, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_9S7aFLUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9S7aFLUD, m);
  cMsg_3s4ANaFZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_pHhKxRR6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_WYWraoDW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_SrqgKX5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bU36RVet_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_kCggm0SS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FRnGrm4u_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BXgVdReF, 2, m, &cDelay_BXgVdReF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ubigjRmQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bU36RVet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_kCggm0SS, 0, m, &hTable_kCggm0SS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vHwEZomc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_SrqgKX5E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3s4ANaFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_kCggm0SS, 0, m, &hTable_kCggm0SS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ubigjRmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BXgVdReF, 0, m, &cDelay_BXgVdReF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FRnGrm4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9S7aFLUD, 2, m, &cDelay_9S7aFLUD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WYWraoDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pxiBbMhF, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_u6amFfRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TwNeZLkU, HV_BINOP_MULTIPLY, 0, m, &cBinop_TwNeZLkU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6EGj0EEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HyqPZnzR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_HyqPZnzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0BQIOucn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TwNeZLkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YImcegBp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_X9HpxKue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TwNeZLkU, HV_BINOP_MULTIPLY, 1, m, &cBinop_TwNeZLkU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0BQIOucn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_X9HpxKue_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YImcegBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_x8r9K3nj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x8r9K3nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JLd8s1Fn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EuSVaxHF, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JLd8s1Fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lZTmoLyf, m);
}

void Heavy_WSTD_FL3NGR::cVar_ZTDYFtym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lnv3f0H3, HV_BINOP_MULTIPLY, 0, m, &cBinop_Lnv3f0H3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_56rRyezK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_m51Y5EBC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_m51Y5EBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aAjuPlL3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Lnv3f0H3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LQnWKiD1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_edbD8pBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lnv3f0H3, HV_BINOP_MULTIPLY, 1, m, &cBinop_Lnv3f0H3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_aAjuPlL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_edbD8pBn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LQnWKiD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QL0OvDsy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QL0OvDsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ih2Qhyxq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GAnhxXuw, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ih2Qhyxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8pz8pGUv, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IlEuDiwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K9KPnW4d, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_MPRQfc5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_qCfIkpE6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Xqtf8zOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_MPRQfc5k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3v4QQB56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_w54gn4li_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2k7b5fAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9xGzdWPi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9xGzdWPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gFjDoEQY, HV_BINOP_MULTIPLY, 1, m, &cBinop_gFjDoEQY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w54gn4li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_2k7b5fAE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gFjDoEQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oYKpQA1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qCfIkpE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gFjDoEQY, HV_BINOP_MULTIPLY, 0, m, &cBinop_gFjDoEQY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oYKpQA1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rGPeCBbO, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_kWb1Gl14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_ob3nmg5f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ob3nmg5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3v4QQB56_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xqtf8zOk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_KhtrnT1y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PPuNlCrY, 0, m, &cSlice_PPuNlCrY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6C3X5czI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_PPuNlCrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MM0yEuzE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MM0yEuzE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_NXjniUWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MM0yEuzE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MM0yEuzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AFNFBjci_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_6C3X5czI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fGFRfInM, 0, m, &cSlice_fGFRfInM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0ttSYVtX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fGFRfInM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WOOjhKQs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WOOjhKQs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Y5CM0pqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WOOjhKQs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_WOOjhKQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DjcUH9qq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_0ttSYVtX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bvbFfpw5, 0, m, &cSlice_bvbFfpw5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NDZDEyB0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_bvbFfpw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_T74X2ehx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_T74X2ehx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_GRaXrEda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T74X2ehx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_T74X2ehx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_11DaGyjT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_NDZDEyB0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HaQdasXf, 0, m, &cSlice_HaQdasXf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_HaQdasXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qE9Gy4vI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qE9Gy4vI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_rhZHTzW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qE9Gy4vI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_qE9Gy4vI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XxnU5tLP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GMUagKFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7Lc04QrL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VWXuTIRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PKaWmDGr, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_aIaYFmj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_f8Xx8RAb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f8Xx8RAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_eQBLPEE1, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Yd01ygzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_D8MlTmIJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_D8MlTmIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6fuLIBsl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_uE9t7Tqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yZ8OdJTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_RnwZ2vA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WnWzxZkM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Utu5qY8F, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6fuLIBsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5hmgaPpr, m);
}

void Heavy_WSTD_FL3NGR::cMsg_yZ8OdJTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RnwZ2vA3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WnWzxZkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Gyp2w2xF, m);
}

void Heavy_WSTD_FL3NGR::cMsg_9EkLtmbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NwUhZh3A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_NwUhZh3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cEhE9E4C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_s4RFkkwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ipqRyWhM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_DnKtPJu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n5VRfsx6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kmdpicXe, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cEhE9E4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OvgxkEYh, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ipqRyWhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DnKtPJu3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_n5VRfsx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sr9MCtHE, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vsUywR09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ecLOEzM8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ecLOEzM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_HlWGITU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_EHfMfG7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B33y54fw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_GIn0EZbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UHN5Kxde_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HlWGITU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bbjiAcUV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bbjiAcUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m3czEBuR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aR30BY5U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_m3czEBuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WgXkwFNu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aR30BY5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y0fWobEh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WgXkwFNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4PUml9pS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_y0fWobEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_w5q6HTJW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w5q6HTJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BkRmPpvL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4PUml9pS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_EHfMfG7q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BkRmPpvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_GIn0EZbG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DndbyBAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aCFG6VXC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aCFG6VXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G0pAMpMi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_yBE9pWOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bppuHt4d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_bppuHt4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EyoBFj5h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_FG7vWTVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FG7vWTVw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jZtAK5GF, 0, m, &cDelay_jZtAK5GF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FG7vWTVw, 0, m, &cDelay_FG7vWTVw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Sv6mGyRg, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_jZtAK5GF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jZtAK5GF, m);
  cMsg_ScKkGGqo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_aug47wZP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_rYJ0N9Xk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_UzfrH0E0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QXQcNkk1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_Xo7Z9t0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KkXB2dL1_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FG7vWTVw, 2, m, &cDelay_FG7vWTVw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XZuOr8mi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QXQcNkk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Xo7Z9t0p, 0, m, &hTable_Xo7Z9t0p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EyoBFj5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_UzfrH0E0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ScKkGGqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Xo7Z9t0p, 0, m, &hTable_Xo7Z9t0p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XZuOr8mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FG7vWTVw, 0, m, &cDelay_FG7vWTVw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KkXB2dL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_jZtAK5GF, 2, m, &cDelay_jZtAK5GF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rYJ0N9Xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Sv6mGyRg, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_crT37Yiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BUjg1YuP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_BUjg1YuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qfH5z1vA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_K2wcR8pJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K2wcR8pJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AWPQzbQv, 0, m, &cDelay_AWPQzbQv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K2wcR8pJ, 0, m, &cDelay_K2wcR8pJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ru4L2EBX, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_AWPQzbQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AWPQzbQv, m);
  cMsg_s3YT6gCT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_VtPG66I1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Q5fLrDqW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_CVvTkhru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jYPFcTFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_GYN2Aky9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7VaOG3Bm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K2wcR8pJ, 2, m, &cDelay_K2wcR8pJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wI9PD27h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jYPFcTFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_GYN2Aky9, 0, m, &hTable_GYN2Aky9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qfH5z1vA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_CVvTkhru_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_s3YT6gCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_GYN2Aky9, 0, m, &hTable_GYN2Aky9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wI9PD27h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_K2wcR8pJ, 0, m, &cDelay_K2wcR8pJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7VaOG3Bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_AWPQzbQv, 2, m, &cDelay_AWPQzbQv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Q5fLrDqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ru4L2EBX, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_PEoJeEDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aKEvWSDO, HV_BINOP_MULTIPLY, 0, m, &cBinop_aKEvWSDO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AsV4P7vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L9JrL1pn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_L9JrL1pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KKniZW54_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aKEvWSDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_alhoZnjP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FpN3vLiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aKEvWSDO, HV_BINOP_MULTIPLY, 1, m, &cBinop_aKEvWSDO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KKniZW54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FpN3vLiQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_alhoZnjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zi73aaWE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zi73aaWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NIVvA0Ss_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZYHkapsm, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NIVvA0Ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iXYq3yXm, m);
}

void Heavy_WSTD_FL3NGR::cVar_jbJnrXMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ydnNL0gQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_ydnNL0gQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ltbXoJNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EVMOlrDU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_EVMOlrDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pSlV088U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ydnNL0gQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uOW8OjZC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yDIjDLLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ydnNL0gQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_ydnNL0gQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pSlV088U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yDIjDLLe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uOW8OjZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LsXWtj5Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LsXWtj5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_AOjX5fJV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gyhsXw1Z, m);
}

void Heavy_WSTD_FL3NGR::cBinop_AOjX5fJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8kaEyKTA, m);
}

void Heavy_WSTD_FL3NGR::cMsg_G0pAMpMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X2SPExBU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_jpkw2tQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_Xv282qEk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lmPYvNeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_jpkw2tQq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_100JZRxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yYmwTkbZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BkEfGIGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PL0VG28A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PL0VG28A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U3jGiZKY, HV_BINOP_MULTIPLY, 1, m, &cBinop_U3jGiZKY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yYmwTkbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_BkEfGIGN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U3jGiZKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rTiKdAmu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Xv282qEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U3jGiZKY, HV_BINOP_MULTIPLY, 0, m, &cBinop_U3jGiZKY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rTiKdAmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hl2BfCPM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ko3dkOb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_Jok2Ubsz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Jok2Ubsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_100JZRxX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lmPYvNeI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_E4rHtMNC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4SFTlRKa, 0, m, &cSlice_4SFTlRKa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CzOypwlD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4SFTlRKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MQjPd5FC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MQjPd5FC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_snKIjiii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MQjPd5FC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MQjPd5FC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WNiXTHQV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_CzOypwlD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6hBq2Bv8, 0, m, &cSlice_6hBq2Bv8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zB9JPA9A_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_6hBq2Bv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ECt8fJ3B_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ECt8fJ3B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_hIFIiQgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ECt8fJ3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ECt8fJ3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o0y4xfeX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zB9JPA9A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1GFy6nUT, 0, m, &cSlice_1GFy6nUT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kkcKDUoX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_1GFy6nUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DTC54204_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DTC54204_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Fm11njv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DTC54204_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DTC54204_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2sD1Duq1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_kkcKDUoX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ed0FRZvw, 0, m, &cSlice_Ed0FRZvw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Ed0FRZvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aTs6AiYW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aTs6AiYW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_x4msGgmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aTs6AiYW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_aTs6AiYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xzDzcc3C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_B33y54fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_klPNvaUU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_UHN5Kxde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s4B6tdZE, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5MFblaR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mXq1OdM1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UC3HsCQ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xmtPmVEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mXq1OdM1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UC3HsCQ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4or0Dq3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mXq1OdM1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UC3HsCQ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_PbRETR20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mXq1OdM1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UC3HsCQ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RnCuHwWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mXq1OdM1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UC3HsCQ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zRJcmqFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_PWEkPoB1, 0, m, &cVar_PWEkPoB1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UXy0BcZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_wtgpdLqU, 0, m, &cVar_wtgpdLqU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sMGatU7M, 0, m, &cVar_sMGatU7M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W4HWb10L, 0, m, &cVar_W4HWb10L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KrtHxBmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LeRWee74_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_j7UTXRjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LeRWee74_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_s33epVpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LeRWee74_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_O8KcVNKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LeRWee74_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_KVCoaca9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sRuVjGyj, 0, m, &cVar_sRuVjGyj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YRC91fIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3EOk7sDA, 0, m, &cVar_3EOk7sDA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jjQQMeuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yC0kwlHy, 0, m, &cVar_yC0kwlHy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pVa8iJTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KhtrnT1y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MagHOw2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KhtrnT1y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oBGQUatg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KhtrnT1y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IA2rgkDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KhtrnT1y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_1WBQDg8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UU0SainA, 0, m, &cVar_UU0SainA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CqvcXmmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7G0My9hB, 0, m, &cVar_7G0My9hB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xBnwEvEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AjtDq3fy, 0, m, &cVar_AjtDq3fy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wvZhOhFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E4rHtMNC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JMxTJtPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E4rHtMNC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_bkThAcuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E4rHtMNC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QdGpmmzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E4rHtMNC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ti0AXed5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Nqw6WoQm, 0, m, &cVar_Nqw6WoQm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nxIbYRvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M77yGMhO, 0, m, &cVar_M77yGMhO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_04gEIWAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tPZ7nUCF, 0, m, &cVar_tPZ7nUCF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zv954Atj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wtgpdLqU, 0, m, &cVar_wtgpdLqU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6uCDituw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sMGatU7M, 0, m, &cVar_sMGatU7M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_QhRdmFCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W4HWb10L, 0, m, &cVar_W4HWb10L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0LpEIeH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sssQKNeL, 0, m, &cVar_sssQKNeL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_x9GYn4Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yQqLnF51_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z82hl4Lg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qXe6JI7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GBsopdXy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZTyjpUdj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y7kk7gUX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qdWd8rUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sW6mF9m0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eYnUKF4j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vr40PKPt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5RtPfQdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Hdpp1U1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT7kM7ko_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zEDzXL4Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_iLSUFGQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rquFqQbv_sendMessage(_c, 0, m);
  cMsg_ETSv5PZX_sendMessage(_c, 0, m);
  cMsg_zZepVInM_sendMessage(_c, 0, m);
  cMsg_Nf6Uk8K6_sendMessage(_c, 0, m);
  cMsg_lbaqjaJm_sendMessage(_c, 0, m);
  cMsg_plTc3mLu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_X2PvYgnA, 0, m, &cVar_X2PvYgnA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sssQKNeL, 0, m, &cVar_sssQKNeL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RVjr0zRQ, 0, m, &cVar_RVjr0zRQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AoDJzqBA, 0, m, &cVar_AoDJzqBA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1UepeG6k, 0, m, &cVar_1UepeG6k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AAP8hLw4, 0, m, &cVar_AAP8hLw4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ouvaGJcO, 0, m, &cVar_ouvaGJcO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y2qN3WzS, 0, m, &cVar_Y2qN3WzS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S5MFS31A, 0, m, &cVar_S5MFS31A_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4blRqV5Q, 0, m, &cVar_4blRqV5Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qokbJz24, 0, m, &cVar_qokbJz24_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CJGlTnj0, 0, m, &cVar_CJGlTnj0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mDUe8qka, 0, m, &cVar_mDUe8qka_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1kjYOVNu, 0, m, &cVar_1kjYOVNu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qxNJPTSN, 0, m, &cVar_qxNJPTSN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QkHmH2tF, 0, m, &cVar_QkHmH2tF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R7eSTPqx, 0, m, &cVar_R7eSTPqx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rrtRN31k, 0, m, &cVar_rrtRN31k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SWiE0Wif, 0, m, &cVar_SWiE0Wif_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cwAmP1iJ, 0, m, &cVar_cwAmP1iJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WRk1VsD8, 0, m, &cVar_WRk1VsD8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WCf62iS9, 0, m, &cVar_WCf62iS9_sendMessage);
  cMsg_7op9gWsD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bLesO6Xc, 0, m, &cVar_bLesO6Xc_sendMessage);
  cMsg_z7VFwOPN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YWzVC7Ij, 0, m, &cVar_YWzVC7Ij_sendMessage);
  cMsg_6EGj0EEP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_u6amFfRW, 0, m, &cVar_u6amFfRW_sendMessage);
  cMsg_56rRyezK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZTDYFtym, 0, m, &cVar_ZTDYFtym_sendMessage);
  cMsg_AsV4P7vf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PEoJeEDj, 0, m, &cVar_PEoJeEDj_sendMessage);
  cMsg_ltbXoJNy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jbJnrXMA, 0, m, &cVar_jbJnrXMA_sendMessage);
  cMsg_L4wpGxFz_sendMessage(_c, 0, m);
  cMsg_IO3qgFx2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0gXsmoVI, 0, m, &cVar_0gXsmoVI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LBKYOGL9, 0, m, &cVar_LBKYOGL9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5RLErKEh, 0, m, &cVar_5RLErKEh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RovbXoLN, 0, m, &cVar_RovbXoLN_sendMessage);
  cMsg_wHrU4paI_sendMessage(_c, 0, m);
  cMsg_oAH1JsHm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NXjniUWF, 0, m, &cVar_NXjniUWF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y5CM0pqI, 0, m, &cVar_Y5CM0pqI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GRaXrEda, 0, m, &cVar_GRaXrEda_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rhZHTzW5, 0, m, &cVar_rhZHTzW5_sendMessage);
  cMsg_yBE9pWOc_sendMessage(_c, 0, m);
  cMsg_crT37Yiv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_snKIjiii, 0, m, &cVar_snKIjiii_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hIFIiQgU, 0, m, &cVar_hIFIiQgU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Fm11njv5, 0, m, &cVar_Fm11njv5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x4msGgmD, 0, m, &cVar_x4msGgmD_sendMessage);
  cMsg_UXy0BcZr_sendMessage(_c, 0, m);
  cMsg_zRJcmqFM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mKbGJRZB, 0, m, &cVar_mKbGJRZB_sendMessage);
  cMsg_jPMzpPWm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vOmCoXr2, 0, m, &cVar_vOmCoXr2_sendMessage);
  cMsg_fKFcYMwb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Zk4K6euJ, 0, m, &cVar_Zk4K6euJ_sendMessage);
  cMsg_gd0mVNf8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5uacf59a, 0, m, &cVar_5uacf59a_sendMessage);
  cMsg_5bx9pg11_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uE9t7Tqi, 0, m, &cVar_uE9t7Tqi_sendMessage);
  cMsg_Yd01ygzl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_s4RFkkwY, 0, m, &cVar_s4RFkkwY_sendMessage);
  cMsg_9EkLtmbY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_eilDs5Qi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZgIBhIwO, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZgIBhIwO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uItSXrmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tmTd1PAu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OedZErCd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ailp3a7d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Khz7nlGK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BdGzYj0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8rXvUaPU_sendMessage);
  cMsg_kkCJ8v9d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_D5NigflJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o8HSPufw, HV_BINOP_MULTIPLY, 0, m, &cBinop_o8HSPufw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tTcUsQA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_CoZKQYzJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rNbvffxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VDcdC9Hh, HV_BINOP_MULTIPLY, 1, m, &cBinop_VDcdC9Hh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BZtR1L8n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Lz649KoL_sendMessage);
  cMsg_HTOQoFFI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_eDC95jbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0bFYB3t9, HV_BINOP_MULTIPLY, 0, m, &cBinop_0bFYB3t9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VFk3yPIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ULMQJRnD_sendMessage(_c, 0, m);
  cMsg_N5iEwMRw_sendMessage(_c, 0, m);
  cMsg_ImWY7qvf_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PCkWkO7P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_aigRTZCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mgxMfmlA_sendMessage);
  cMsg_CoH9EiVw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_ruWcj7Se_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1UepeG6k, 0, m, &cVar_1UepeG6k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Dl6ytt0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PCWqDw6S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ElHCglIA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_e0LSqNrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MesrYYk6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XXUlhwlZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oSZYS7RQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5e7LBvPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mnf6eZmk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b6orMfcE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pE2OG9yU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Idb7CuEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_96tNTVHj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q7qkxAuV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KFyIF9uW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_hmQns5Az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mdzOhjcV, HV_BINOP_MULTIPLY, 0, m, &cBinop_mdzOhjcV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_FMymMqIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_J2gWHkhT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7AUEdvgv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NF2KLbwN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ylwNHvR5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bRX01jil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qeklXcDV_sendMessage);
  cMsg_mbA3hGKT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_4myPhqcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dsCkOFmO, HV_BINOP_MULTIPLY, 0, m, &cBinop_dsCkOFmO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_mWePdMKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PEk0w3Mj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_U3TbIwKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SAENSLz0, HV_BINOP_MULTIPLY, 1, m, &cBinop_SAENSLz0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_n23p2oYW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pNOUnPeW_sendMessage);
  cMsg_qS8YHITP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_vkrPsDqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsjXej8X, HV_BINOP_MULTIPLY, 0, m, &cBinop_KsjXej8X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_83l9hmek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BBxaaVxz_sendMessage(_c, 0, m);
  cMsg_no4Ojj8y_sendMessage(_c, 0, m);
  cMsg_YtMni3Tv_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_cxbPldlW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jOCiZjVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_keylxOLP_sendMessage);
  cMsg_AR9WKqP0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_UfgJ2HtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PWEkPoB1, 0, m, &cVar_PWEkPoB1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_PXIKBCru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_KVCoaca9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_a1zMSSoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_YRC91fIm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ppaQAD4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hgKWrsox, 0, m, &cVar_hgKWrsox_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kBnOrwPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_jjQQMeuO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LjeYSgFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1WBQDg8J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fuNzNeV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CqvcXmmE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tmbNtN3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZT9NibBe, 0, m, &cVar_ZT9NibBe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_G3Z303EU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_xBnwEvEQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6zFHfULs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ti0AXed5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_PIPbiKby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nxIbYRvB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_13i1aztm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3evq9t8A, 0, m, &cVar_3evq9t8A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_sIPmI9bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_04gEIWAp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Fql7Q01p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_dTGgfe5F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_eLv9h83T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_84Epnagc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_mjDXy6SG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SFvh2Cs5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kuwp9psa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sGNXmO78_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_11DaGyjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_8Pcp0cUm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DjcUH9qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_kWb1Gl14_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XxnU5tLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Y9we22PN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_AFNFBjci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Sa7tzn8Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2sD1Duq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_aIaYFmj3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_o0y4xfeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ko3dkOb7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xzDzcc3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vsUywR09_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_WNiXTHQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DndbyBAu_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_UyBlHbGN, VOf(Bf0));
    __hv_line_f(&sLine_GfSDgodm, VOf(Bf1));
    __hv_line_f(&sLine_Jcsi5RKj, VOf(Bf2));
    __hv_line_f(&sLine_8mDJExTU, VOf(Bf3));
    __hv_line_f(&sLine_yOqAnyen, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_yd8cOvUV, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_5vo1R0T3, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_KgWWoASw, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_HNBfDR7m, VOf(Bf1));
    __hv_line_f(&sLine_041Y24p5, VOf(Bf0));
    __hv_line_f(&sLine_3ZS4U94s, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_8C9HUTKH, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_ibfFNT0o, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_zqRGVldx, VOf(Bf5));
    __hv_line_f(&sLine_55e7LEFj, VOf(Bf1));
    __hv_line_f(&sLine_I6iQ5Dl1, VOf(Bf2));
    __hv_line_f(&sLine_f0jLkSE3, VOf(Bf4));
    __hv_line_f(&sLine_0EPEu8zM, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_XAUBpKDt, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_fV8WkFqc, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_omuzDoar, VOf(Bf6));
    __hv_line_f(&sLine_Knjtg7lq, VOf(Bf2));
    __hv_line_f(&sLine_43cUCiCI, VOf(Bf1));
    __hv_line_f(&sLine_kF9IYD2D, VOf(Bf5));
    __hv_line_f(&sLine_XBdSMZNu, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_gUWSQppA, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_nDd1nS4G, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_8XYj1W8Q, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_MvrIKQ1z, VOf(Bf2));
    __hv_line_f(&sLine_4B38cixE, VOf(Bf6));
    __hv_line_f(&sLine_wuqz9BV6, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_sI049mM8, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_JKjxJPpV, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_lRWi48u1, VOf(Bf8));
    __hv_line_f(&sLine_02MIuWpd, VOf(Bf2));
    __hv_line_f(&sLine_9CpKXfg5, VOf(Bf1));
    __hv_line_f(&sLine_ojllg8oB, VOf(Bf7));
    __hv_line_f(&sLine_r93ah6Ha, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_Rp1yDbcg, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_BGWe4SNr, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_fPy7S1Lw, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_JK0yXyOj, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_VQsFiIZ6, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_FuAzozEr, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_IQM4JsJ6, VOf(Bf8));
    __hv_rpole_f(&sRPole_dxa3ooJ7, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_Ku0Pyl5j, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_SEvY4NEY, VOf(Bf10));
    __hv_rpole_f(&sRPole_LTElx4B3, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_E53RgqeD, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_sV6X7RHD, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_cqKbcPsX, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_p3igAnY2, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_xlYXKQEY, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_upzAvKBI, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_m22joC8F, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_u0dkb80b, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_blIDUBlE, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_hmAX9mia, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_3umjQUni, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_AQdAyFVp, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_9mWVf6Qr, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_sZVOsb6g, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_JCiXHnIr, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_fxBynssm, VIf(Bf3));
    __hv_varwrite_f(&sVarf_TUTuWxc3, VIf(Bf11));
    __hv_line_f(&sLine_PKaWmDGr, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_7vZAAs1m, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_K9KPnW4d, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_EuSVaxHF, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_lZTmoLyf, VOf(Bf10));
    __hv_rpole_f(&sRPole_OFJRL5i7, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_GAnhxXuw, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_8pz8pGUv, VOf(Bf5));
    __hv_rpole_f(&sRPole_B0xdvwD7, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_sVRCP0zD, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_lk8QE2fb, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_XRCbU3um, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_CZA3HfAf, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_2a9Sc9W0, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_P2wNITmi, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_7Lc04QrL, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_ShpwhOqK, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_OAQsQDpr, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_3dYf257f, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_7OUNq3t5, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_rgtl8ZLO, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_3boll6hd, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_rGPeCBbO, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_KCnjTLWG, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_pxiBbMhF, VIf(Bf0));
    __hv_varwrite_f(&sVarf_clrm3RN9, VIf(Bf8));
    __hv_line_f(&sLine_s4B6tdZE, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_eQBLPEE1, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_X2SPExBU, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_ZYHkapsm, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_iXYq3yXm, VOf(Bf5));
    __hv_rpole_f(&sRPole_kRw3wPos, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_gyhsXw1Z, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_8kaEyKTA, VOf(Bf6));
    __hv_rpole_f(&sRPole_NW8eAYDd, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_yEmEXCFR, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_5hmgaPpr, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Gyp2w2xF, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_Utu5qY8F, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_8xhgTnsJ, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_2NrVyT9I, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_klPNvaUU, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_uoYMILOs, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_OvgxkEYh, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_sr9MCtHE, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_kmdpicXe, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_d8C9FCcU, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_I1mzJgVO, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_Hl2BfCPM, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_Sv6mGyRg, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_ru4L2EBX, VIf(Bf4));
    __hv_varwrite_f(&sVarf_K7JCyqup, VIf(Bf10));
    __hv_varwrite_f(&sVarf_Txpx3K0b, VIf(Bf2));
    __hv_varwrite_f(&sVarf_DeDLDalo, VIf(Bf9));
    __hv_varwrite_f(&sVarf_0XDXbL1u, VIf(Bf11));
    __hv_varread_f(&sVarf_TUTuWxc3, VOf(Bf11));
    __hv_varread_f(&sVarf_clrm3RN9, VOf(Bf9));
    __hv_varread_f(&sVarf_K7JCyqup, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_Txpx3K0b, VOf(Bf2));
    __hv_varread_f(&sVarf_DeDLDalo, VOf(Bf11));
    __hv_varread_f(&sVarf_0XDXbL1u, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
